==> proshade-0.7.6.0.tar.gz: proshade-0.7.6.0/proshade/documentation/html/_pro_s_h_a_d_e__symmetry_8hpp.js <==
var _pro_s_h_a_d_e__symmetry_8hpp =
[
    [ "addAxisUnlessSame", "_pro_s_h_a_d_e__symmetry_8hpp.html#a262d9e21cd6b81b8bda35ec22eb363dd", null ],
    [ "addAxisUnlessSame", "_pro_s_h_a_d_e__symmetry_8hpp.html#a00a784fd675e871b3b032d8f62013262", null ],
    [ "addZeroPeakToGroups", "_pro_s_h_a_d_e__symmetry_8hpp.html#ade9b717260e86c8f24bcbe6d17fe4e06", null ],
    [ "checkExpectedAgainstFound", "_pro_s_h_a_d_e__symmetry_8hpp.html#a074d9c1d40d7491ea9f9f9639744e18d", null ],
    [ "checkFittingAxisDualAndSave", "_pro_s_h_a_d_e__symmetry_8hpp.html#a210ee0af651d440b68168882ead71c66", null ],
    [ "checkFittingAxisTripleAndSave", "_pro_s_h_a_d_e__symmetry_8hpp.html#a194944b48a4b6b523ef251a2a03eab17", null ],
    [ "checkForMissingPeak", "_pro_s_h_a_d_e__symmetry_8hpp.html#aacced7feb8ce5251dce199505912d997", null ],
    [ "completeMissingCSymmetry", "_pro_s_h_a_d_e__symmetry_8hpp.html#a9304bbd5138aaa9e4f4aed4676af6256", null ],
    [ "detectIcosahedralSymmetry", "_pro_s_h_a_d_e__symmetry_8hpp.html#a4f09b90de1f15b345ee7998ff31327f3", null ],
    [ "detectOctahedralSymmetry", "_pro_s_h_a_d_e__symmetry_8hpp.html#a18d456057604616a7cf6b68f59b4f2d0", null ],
    [ "detectTetrahedralSymmetry", "_pro_s_h_a_d_e__symmetry_8hpp.html#a37925ac477480c718451debb01a9c74a", null ],
    [ "determineFoldToTry", "_pro_s_h_a_d_e__symmetry_8hpp.html#ac0a8dc71c37de02256521ebc9178c8d4", null ],
    [ "findExpectedPeakRotations", "_pro_s_h_a_d_e__symmetry_8hpp.html#af4f982fc282e8fca11b6a85f2d2069a5", null ],
    [ "findIcos10C3s", "_pro_s_h_a_d_e__symmetry_8hpp.html#aa0df823fdb0d1f187f160f884f220327", null ],
    [ "findIcos15C2s", "_pro_s_h_a_d_e__symmetry_8hpp.html#a81b6825a5467ac570ebe9a3167cda9e2", null ],
    [ "findIcos6C5s", "_pro_s_h_a_d_e__symmetry_8hpp.html#a8e5edd0504efb95ecf9caf51661d5aa4", null ],
    [ "findMissingAxes", "_pro_s_h_a_d_e__symmetry_8hpp.html#af6093da290ce7b73a33e8b55f2c83491", null ],
    [ "findMissingAxesDual", "_pro_s_h_a_d_e__symmetry_8hpp.html#a6d9f533a789bd5c6031fa77b9649ed3d", null ],
    [ "findMissingAxesTriple", "_pro_s_h_a_d_e__symmetry_8hpp.html#ae266053664eb7cf916aa5e2d282e35dd", null ],
    [ "findMissingAxisPoints", "_pro_s_h_a_d_e__symmetry_8hpp.html#a465606e58df7d6a2238d40c6919b2e58", null ],
    [ "findOcta3C4s", "_pro_s_h_a_d_e__symmetry_8hpp.html#a870671b74f645f535f327c397826d6c9", null ],
    [ "findOcta4C3s", "_pro_s_h_a_d_e__symmetry_8hpp.html#a0a35a745745fa3db227455241bb083ae", null ],
    [ "findOcta6C2s", "_pro_s_h_a_d_e__symmetry_8hpp.html#a62c8dc8fe0c14305d2d715a22c7042aa", null ],
    [ "findPeaksByHeightBoundaries", "_pro_s_h_a_d_e__symmetry_8hpp.html#a2137fa16a69fc7a8365439e322b67dc8", null ],
    [ "findPeaksCSymmetry", "_pro_s_h_a_d_e__symmetry_8hpp.html#a648ddad98891a4d8a6af5187d994c5ec", null ],
    [ "findPredictedAxesHeights", "_pro_s_h_a_d_e__symmetry_8hpp.html#a33c650c19a6954800bba6b3a8f5842e6", null ],
    [ "findPredictedSingleAxisHeight", "_pro_s_h_a_d_e__symmetry_8hpp.html#a58c00659b5f6abf315fb5a426c45810c", null ],
    [ "findSymmetryUsingFold", "_pro_s_h_a_d_e__symmetry_8hpp.html#a580f68aa45b9b4f66dff3a4d5daaa316", null ],
    [ "findTetra3C2s", "_pro_s_h_a_d_e__symmetry_8hpp.html#adac314dce30ead61ca122c991e4a9671", null ],
    [ "findTetra4C3s", "_pro_s_h_a_d_e__symmetry_8hpp.html#a754f8c240a6a0bfc2dac842e4cfafb58", null ],
    [ "getPeaksAngleAxisPositions", "_pro_s_h_a_d_e__symmetry_8hpp.html#acc08b5c3e227d4671a208cdd68d5c80c", null ],
    [ "giveOppositeAxesSameDirection", "_pro_s_h_a_d_e__symmetry_8hpp.html#a41150b2f8995b2ac1f144143fc83b6ee", null ],
    [ "groupSameAxes", "_pro_s_h_a_d_e__symmetry_8hpp.html#a98538547e5bcc6192bbbea1d7b51c537", null ],
    [ "isSymmetrySame", "_pro_s_h_a_d_e__symmetry_8hpp.html#ad977c265833d6466598cceb406a085db", null ],
    [ "isSymmetrySame", "_pro_s_h_a_d_e__symmetry_8hpp.html#a10af3702dc9022c3afcaf72b049779f3", null ],
    [ "missingAxisHeight", "_pro_s_h_a_d_e__symmetry_8hpp.html#ad44ed609e8a3d59674b2b2256aec41f8", null ],
    [ "predictIcosAxes", "_pro_s_h_a_d_e__symmetry_8hpp.html#a16d3cf24f73eafc1d5b8ef9e204aaf8d", null ],
    [ "predictOctaAxes", "_pro_s_h_a_d_e__symmetry_8hpp.html#a38ce8efbbe05220793b5f01f0fef07a6", null ],
    [ "predictTetraAxes", "_pro_s_h_a_d_e__symmetry_8hpp.html#aef7a2435e9d3616d860aeee2d94dba55", null ],
    [ "printSymmetryCompletion", "_pro_s_h_a_d_e__symmetry_8hpp.html#aac0456f55cb3bf83707cc3b493e32fb3", null ],
    [ "printSymmetryGroup", "_pro_s_h_a_d_e__symmetry_8hpp.html#af4b044752fe0a780a3f09743e9d8d58e", null ],
    [ "printSymmetryPeaks", "_pro_s_h_a_d_e__symmetry_8hpp.html#af9835b91e354e4615beb79b5c2a674e9", null ],
    [ "saveAllCSymmetries", "_pro_s_h_a_d_e__symmetry_8hpp.html#a870711ceabba16c8fc79bd93d26b11a8", null ],
    [ "saveDetectedCSymmetry", "_pro_s_h_a_d_e__symmetry_8hpp.html#a5dda335a87d6c26edfd3cf2a29ff7f1f", null ],
    [ "saveDSymmetry", "_pro_s_h_a_d_e__symmetry_8hpp.html#ab0ac919dd609bc6bded806c0f78201fd", null ],
    [ "saveMissingAxisNewOnly", "_pro_s_h_a_d_e__symmetry_8hpp.html#a5dc4353223fc752e0007b2adec193079", null ],
    [ "searchMissingSymmetrySpace", "_pro_s_h_a_d_e__symmetry_8hpp.html#a1ada2416687dbb0bec93603770cb4c83", null ],
    [ "smallestDistanceBetweenAngles", "_pro_s_h_a_d_e__symmetry_8hpp.html#a2b3fcf4dd97e677da27192cf63dbb678", null ],
    [ "sortArrVecHlp", "_pro_s_h_a_d_e__symmetry_8hpp.html#a68d576f90449b7d3fcf5ae4d3114c268", null ],
    [ "testGroupAgainstGroup", "_pro_s_h_a_d_e__symmetry_8hpp.html#a5360c152697780177eb2676888cd5108", null ],
    [ "testGroupAgainstSymmetry", "_pro_s_h_a_d_e__symmetry_8hpp.html#ad8c193e95c7069fafa78dccc1de1aaa4", null ]
];

==> proshade-0.7.6.5.tar.gz: proshade-0.7.6.5/proshade/documentation/html/_pro_s_h_a_d_e__symmetry_8hpp.js <==
var _pro_s_h_a_d_e__symmetry_8hpp =
[
    [ "addAxisUnlessSame", "_pro_s_h_a_d_e__symmetry_8hpp.html#a262d9e21cd6b81b8bda35ec22eb363dd", null ],
    [ "addAxisUnlessSame", "_pro_s_h_a_d_e__symmetry_8hpp.html#a00a784fd675e871b3b032d8f62013262", null ],
    [ "allocateCentreOfMapFourierTransforms", "_pro_s_h_a_d_e__symmetry_8hpp.html#a952318f67deb547d73ae3ed62ee6d5c4", null ],
    [ "checkFittingAxisDualAndSave", "_pro_s_h_a_d_e__symmetry_8hpp.html#a210ee0af651d440b68168882ead71c66", null ],
    [ "checkFittingAxisTripleAndSave", "_pro_s_h_a_d_e__symmetry_8hpp.html#a194944b48a4b6b523ef251a2a03eab17", null ],
    [ "detectIcosahedralSymmetry", "_pro_s_h_a_d_e__symmetry_8hpp.html#a4f09b90de1f15b345ee7998ff31327f3", null ],
    [ "detectOctahedralSymmetry", "_pro_s_h_a_d_e__symmetry_8hpp.html#a18d456057604616a7cf6b68f59b4f2d0", null ],
    [ "detectTetrahedralSymmetry", "_pro_s_h_a_d_e__symmetry_8hpp.html#a37925ac477480c718451debb01a9c74a", null ],
    [ "findIcos10C3s", "_pro_s_h_a_d_e__symmetry_8hpp.html#ab53cd7561731d9426989f5ace523826a", null ],
    [ "findIcos15C2s", "_pro_s_h_a_d_e__symmetry_8hpp.html#a422414bb07db89a5c797f371a5448c0e", null ],
    [ "findIcos6C5s", "_pro_s_h_a_d_e__symmetry_8hpp.html#af4dec365c5650c93198d73b6d259e4e7", null ],
    [ "findMissingAxes", "_pro_s_h_a_d_e__symmetry_8hpp.html#af6093da290ce7b73a33e8b55f2c83491", null ],
    [ "findMissingAxesDual", "_pro_s_h_a_d_e__symmetry_8hpp.html#a6d9f533a789bd5c6031fa77b9649ed3d", null ],
    [ "findMissingAxesTriple", "_pro_s_h_a_d_e__symmetry_8hpp.html#ae266053664eb7cf916aa5e2d282e35dd", null ],
    [ "findMissingAxisPoints", "_pro_s_h_a_d_e__symmetry_8hpp.html#a465606e58df7d6a2238d40c6919b2e58", null ],
    [ "findOcta3C4s", "_pro_s_h_a_d_e__symmetry_8hpp.html#a31e25079d4a20a0d6442c7fb36fdeaea", null ],
    [ "findOcta4C3s", "_pro_s_h_a_d_e__symmetry_8hpp.html#a1db775b80f6ce426bb98d87f8ba99d72", null ],
    [ "findOcta6C2s", "_pro_s_h_a_d_e__symmetry_8hpp.html#a7f24f5b37a7810ce379fce1b71877a0e", null ],
    [ "findPointFromTranslations", "_pro_s_h_a_d_e__symmetry_8hpp.html#a194544dbfe4daae5fe9300daeb98c779", null ],
    [ "findPredictedAxesHeights", "_pro_s_h_a_d_e__symmetry_8hpp.html#a33c650c19a6954800bba6b3a8f5842e6", null ],
    [ "findPredictedSingleAxisHeight", "_pro_s_h_a_d_e__symmetry_8hpp.html#a58c00659b5f6abf315fb5a426c45810c", null ],
    [ "findReliableUnphasedSymmetries", "_pro_s_h_a_d_e__symmetry_8hpp.html#a29b1e5bdc80f63a47d0abff4b66ee6b2", null ],
    [ "findTetra3C2s", "_pro_s_h_a_d_e__symmetry_8hpp.html#a5e5d3ccec33e4cf7204124a5647fe5c9", null ],
    [ "findTetra4C3s", "_pro_s_h_a_d_e__symmetry_8hpp.html#a5d4e5e34da6e4a9ed4a67cca16491c17", null ],
    [ "findTranslationBetweenRotatedAndOriginalMap", "_pro_s_h_a_d_e__symmetry_8hpp.html#a3ec1b87286193d7797b6afa2bed1ea33", null ],
    [ "isSymmetrySame", "_pro_s_h_a_d_e__symmetry_8hpp.html#ad977c265833d6466598cceb406a085db", null ],
    [ "isSymmetrySame", "_pro_s_h_a_d_e__symmetry_8hpp.html#a10af3702dc9022c3afcaf72b049779f3", null ],
    [ "missingAxisHeight", "_pro_s_h_a_d_e__symmetry_8hpp.html#ad44ed609e8a3d59674b2b2256aec41f8", null ],
    [ "optimiseDGroupAngleFromAxesHeights", "_pro_s_h_a_d_e__symmetry_8hpp.html#ae4e9966655e7cfbf988ef38d4653bd69", null ],
    [ "optimiseDGroupAngleFromAxesHeights", "_pro_s_h_a_d_e__symmetry_8hpp.html#a8b39de1c901703986cb476d8cb8cf9dc", null ],
    [ "predictIcosAxes", "_pro_s_h_a_d_e__symmetry_8hpp.html#a16d3cf24f73eafc1d5b8ef9e204aaf8d", null ],
    [ "predictOctaAxes", "_pro_s_h_a_d_e__symmetry_8hpp.html#a38ce8efbbe05220793b5f01f0fef07a6", null ],
    [ "predictTetraAxes", "_pro_s_h_a_d_e__symmetry_8hpp.html#aef7a2435e9d3616d860aeee2d94dba55", null ],
    [ "releaseCentreOfMapFourierTransforms", "_pro_s_h_a_d_e__symmetry_8hpp.html#a4e67dc983f98cde3963b0d805f41ce30", null ],
    [ "saveDSymmetry", "_pro_s_h_a_d_e__symmetry_8hpp.html#ab0ac919dd609bc6bded806c0f78201fd", null ],
    [ "saveMissingAxisNewOnly", "_pro_s_h_a_d_e__symmetry_8hpp.html#a5dc4353223fc752e0007b2adec193079", null ],
    [ "searchMissingSymmetrySpace", "_pro_s_h_a_d_e__symmetry_8hpp.html#a1ada2416687dbb0bec93603770cb4c83", null ],
    [ "sortArrVecHlp", "_pro_s_h_a_d_e__symmetry_8hpp.html#a68d576f90449b7d3fcf5ae4d3114c268", null ],
    [ "testGroupAgainstGroup", "_pro_s_h_a_d_e__symmetry_8hpp.html#a5360c152697780177eb2676888cd5108", null ],
    [ "testGroupAgainstSymmetry", "_pro_s_h_a_d_e__symmetry_8hpp.html#ad8c193e95c7069fafa78dccc1de1aaa4", null ]
];
